<?php
/*
Plugin Name: DB-Views Data Table
Description: Add full database functionality to your website. Display advanced data tables and multistep webforms in any webpage.
Version:     1.0.1
Author:      DB-Views
Author URI:  https://www.db-views.com
Text Domain: db-views-data-table
Domain Path: /languages
*/

defined( 'ABSPATH' ) or die;

define( 'DB_VIEWS_DATA_TABLE_FILE', __FILE__ );
define( 'DB_VIEWS_DATA_TABLE_PLUGIN_PATH', plugin_dir_path( __FILE__ ) );
define( 'DB_VIEWS_DATA_TABLE_VER', '1.0.0' );

if ( ! class_exists( 'DB_View_Data_Table' ) ) {
	class DB_View_Data_Table {
		public static function get_instance() {
			if ( self::$instance == null ) {
				self::$instance = new self();
			}
			return self::$instance;
		}

		private static $instance = null;

		private function __clone() { }

		public function __wakeup() { }

		private function __construct() {
			// Actions
			add_action( 'init', array( $this, 'init' ) );
			add_shortcode( 'db-views', array( $this, 'output_shortcode' ) );
		}

		public function init() {
			load_plugin_textdomain( 'db-views-data-table', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );
		}

		public function output_shortcode( $atts, $content = '', $tag ) {
			extract( shortcode_atts( array(
				'show' => false,
				'width' => false,
				'height' => false,
				'style' => false
			), $atts, $tag ) );

			if ( strlen($show) == 0 ) return __( 'DB-Views Data Table: Invalid show parameter', 'db-views-data-table' );

			$_width = $width ? ' width="' . esc_attr( $width ) . '"' : '';
			$_height = ' height="' . ($height ? esc_attr( $height ) : '400') . '"';
			$_style = ' style="' . ($style ? esc_attr( $style ) : 'border:1px solid black;') . '"';
			$_show = esc_attr( $show );
			$prm = (($_pos = strpos($_show, "?")) !== FALSE) ? substr($_show, $_pos+1) : $_show;
			$app = 'https://web.db-views.app?' . $prm;
			$src = 'src="' . esc_attr( $app ) . '&wp=1"';

			$html = '<iframe ' . $src . $_width . $_height . $_style . '></iframe>';
			return $html;
		}
	}

	DB_View_Data_Table::get_instance();
}